//
//  ViewController.swift
//  PullToRefresh

import UIKit

class ViewController: UIViewController, UITableViewDataSource, UITableViewDelegate {

    @IBOutlet var table: UITableView!
    
    var refreshControl = UIRefreshControl()
    var dateFormatter = NSDateFormatter()

    let url_to_request = "http://www.kaleidosblog.com/tutorial/pulltorefresh.php"
    var last_index = 0
    
    var list:[Int] = [Int]()
    
    
    
    
    
    override func viewDidLoad() {
        super.viewDidLoad()

        
        self.dateFormatter.dateStyle = NSDateFormatterStyle.ShortStyle
        self.dateFormatter.timeStyle = NSDateFormatterStyle.LongStyle
        
        refreshControl.backgroundColor = UIColor.clearColor()
        refreshControl.tintColor = UIColor.blackColor()
        refreshControl.attributedTitle = NSAttributedString(string: "Pull to refresh")
        
        refreshControl.addTarget(self, action: "PullRefresh", forControlEvents: UIControlEvents.ValueChanged)
        
        self.table.addSubview(refreshControl)
     
 
        table.dataSource = self
        table.delegate = self
        
        
        data_request()
    }


    
    internal func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int
    {
        return list.count
    }
    
    
    internal func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell
    {
         let cell = tableView.dequeueReusableCellWithIdentifier("cell", forIndexPath: indexPath) as UITableViewCell
        
         cell.textLabel?.text = list[indexPath.row].description
        
        return cell
    }
    
    
    
    
    func PullRefresh()
    {
        data_request()        
    }
    
    
    

    
    func data_request()
    {
        let url:NSURL = NSURL(string: url_to_request)!
        let session = NSURLSession.sharedSession()
        
        let request = NSMutableURLRequest(URL: url)
        request.HTTPMethod = "POST"
        request.cachePolicy = NSURLRequestCachePolicy.ReloadIgnoringCacheData
        
        let paramString = "last_index=" + last_index.description
        request.HTTPBody = paramString.dataUsingEncoding(NSUTF8StringEncoding)
        
        let task = session.dataTaskWithRequest(request) {
            (
            let data, let response, let error) in
            
            guard let _:NSData = data, let _:NSURLResponse = response  where error == nil else {
                print("error")
                return
            }

            
            self.extract_data(data!)
        }
        
        task.resume()
        
    }
    
    
    func extract_data(data:NSData)
    {
        var json: AnyObject?

        
        do
        {
            json = try NSJSONSerialization.JSONObjectWithData(data, options: [])
        }
        catch
        {
            return
        }
        
        guard let data_array = json as? NSArray else
        {
            return
        }
        
        
        for(var i = 0; i < data_array.count; i++)
        {
            if let add = data_array[i] as? Int
            {
                list.insert(add, atIndex: 0)
                last_index = add
            }
        }
        
        
        dispatch_async(dispatch_get_main_queue(), {
            self.table.reloadData()
            
            let now = NSDate()
            
            let updateString = "Last Updated at " + self.dateFormatter.stringFromDate(now)
           
            self.refreshControl.attributedTitle = NSAttributedString(string: updateString)
            
            
            if self.refreshControl.refreshing
            {
                self.refreshControl.endRefreshing()
            }

            
            return
        })
        
        
    }
    
    
}

